@@ -1,6 +1,16 @@
+# Taking cue from Roger Bivand's maptools:
+.PBSmapEnv <- new.env(FALSE, parent=globalenv())  # be sure to exportPattern("^\\.PBS") in NAMESPACE
+
 .onLoad <- function(lib, pkg)
 {
 	library.dynam("PBSmapping", pkg, lib);
+}
+
+.onAttach <- function(lib, pkg)
+{
+	assign("PBSprint",FALSE,envir=.PBSmapEnv)
+
+	# obtain values necessary for the start-up message
 	pkg_info <- utils::sessionInfo( package="PBSmapping" )$otherPkgs$PBSmapping
 	if( is.character( pkg_info$Packaged ) )
 		pkg_date <- strsplit( pkg_info$Packaged, " " )[[1]][1]
@@ -11,7 +21,7 @@
 	
 	packageStartupMessage("
 -----------------------------------------------------------
-PBS Mapping ", pkg_info$Version, " -- Copyright (C) 2003-2012 Fisheries and Oceans Canada
+PBS Mapping ", pkg_info$Version, " -- Copyright (C) 2003-2013 Fisheries and Oceans Canada
 
 PBS Mapping comes with ABSOLUTELY NO WARRANTY;
 for details see the file COPYING.
@@ -32,6 +42,10 @@ To see demos, type '.PBSfigs()'.
 
 ")
 }
+.onUnload <- function(libpath) {
+	rm(.PBSmapEnv)
+}
+
 # No Visible Bindings
 # ===================
 if(getRversion() >= "2.15.1") utils::globalVariables(names=c(
